Quickstart
===========================================

.. raw:: html

    <script src="https://gist.github.com/semiautomaticgit/f7476c6954186288e267660ad1c3c7fe.js"></script>

Link to the guide:
https://colab.research.google.com/gist/semiautomaticgit/f7476c6954186288e267660ad1c3c7fe/quickstart.ipynb
